==> openbci-0.0.tar.gz: openbci-0.0/setup.py <==
import os
from setuptools import setup

# with open(os.path.join(os.path.dirname(__file__), 'README.md')) as readme:
   #README = readme.read()

os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))
version_str = open(os.path.join('openbci', '_version.txt'), 'r').read().strip()

setup(
    name='openbci',
    version=version_str,
    packages=['openbci', 'openbci.acquisition', 'openbci.preprocess'],

    author='Yeison Cardona',
    author_email='yeisoneng@gmail.com',
    maintainer='Yeison Cardona',
    maintainer_email='yeisoneng@gmail.com',

    # url='http://yeisoncardona.com/',
    download_url='https://bitbucket.org/gcpds/openbci/downloads/',

    install_requires=['pyserial',
                      'scipy>=1.3.1',
                      'numpy',
                      'psutil',
                      'mne',
                      'requests',
                      'tornado',
                      ],


    extras_require={
        'utils': ['systemd_service', 'netifaces', 'python-nmap', 'quickapi'],
    },

    scripts=[
        "cmd/eegstream",
    ],

    include_package_data=True,
    license='Simplified BSD License',
    description="Hight level Python module for OpenBCI hardware by GCPDS.",
    long_description="",
    # long_description=README,


    python_requires='>=3.7',

    classifiers=[
       'Development Status :: 4 - Beta',
       'Intended Audience :: Developers',
       'Intended Audience :: Education',
       'Intended Audience :: Healthcare Industry',
       'Intended Audience :: Science/Research',
       'License :: OSI Approved :: BSD License',
       'Programming Language :: Python :: 3.7',
       'Programming Language :: Python :: 3.8',
       'Topic :: Scientific/Engineering',
       'Topic :: Scientific/Engineering :: Artificial Intelligence',
       'Topic :: Scientific/Engineering :: Human Machine Interfaces',
       'Topic :: Scientific/Engineering :: Medical Science Apps.',
       'Topic :: Software Development :: Embedded Systems',
       'Topic :: Software Development :: Libraries',
       'Topic :: Software Development :: Libraries :: Application Frameworks',
       'Topic :: Software Development :: Libraries :: Python Modules',
       'Topic :: System :: Hardware :: Hardware Drivers',
    ],

)

==> openbci-0.1.tar.gz: openbci-0.1/setup.py <==
import os
from setuptools import setup

# with open(os.path.join(os.path.dirname(__file__), 'README.md')) as readme:
   #README = readme.read()

os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))
version_str = open(os.path.join('openbci', '_version.txt'), 'r').read().strip()

setup(
    name='openbci',
    version=version_str,
    packages=['openbci', 'openbci.acquisition'],

    author='Yeison Cardona',
    author_email='yeisoneng@gmail.com',
    maintainer='Yeison Cardona',
    maintainer_email='yeisoneng@gmail.com',

    # url='http://yeisoncardona.com/',
    download_url='https://bitbucket.org/gcpds/openbci/downloads/',

    install_requires=['pyserial',
                      'scipy>=1.3.1',
                      'numpy',
                      'psutil',
                      'mne',
                      'requests',
                      'tornado',
                      ],


    extras_require={
        'utils': ['systemd_service', 'netifaces', 'python-nmap', 'quickapi'],
    },

    scripts=[
        "cmd/eegstream",
    ],

    include_package_data=True,
    license='Simplified BSD License',
    description="Hight level Python module for OpenBCI hardware by GCPDS.",
    long_description="",
    # long_description=README,


    python_requires='>=3.7',

    classifiers=[
       'Development Status :: 4 - Beta',
       'Intended Audience :: Developers',
       'Intended Audience :: Education',
       'Intended Audience :: Healthcare Industry',
       'Intended Audience :: Science/Research',
       'License :: OSI Approved :: BSD License',
       'Programming Language :: Python :: 3.7',
       'Programming Language :: Python :: 3.8',
       'Topic :: Scientific/Engineering',
       'Topic :: Scientific/Engineering :: Artificial Intelligence',
       'Topic :: Scientific/Engineering :: Human Machine Interfaces',
       'Topic :: Scientific/Engineering :: Medical Science Apps.',
       'Topic :: Software Development :: Embedded Systems',
       'Topic :: Software Development :: Libraries',
       'Topic :: Software Development :: Libraries :: Application Frameworks',
       'Topic :: Software Development :: Libraries :: Python Modules',
       'Topic :: System :: Hardware :: Hardware Drivers',
    ],

)
